
import React, { Suspense } from "react";
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { AuthProvider } from "./providers/AuthProvider";
import { ThemeProvider } from "@/components/theme/theme-provider";
import ProtectedRoute from "./components/auth/ProtectedRoute";
import DashboardLayout from "./components/layout/DashboardLayout";
import CriticalCSSLoader from "@/components/ui/CriticalCSSLoader";
import { useResourceOptimization } from "@/hooks/useResourceOptimization";

// Lazy load components for better performance
const Index = React.lazy(() => import("./pages/Index"));
const ServicosPage = React.lazy(() => import("./pages/Servicos"));
const SobrePage = React.lazy(() => import("./pages/Sobre"));
const ContatoPage = React.lazy(() => import("./pages/Contato"));
const LoginPage = React.lazy(() => import("./pages/Login"));
const ResetPassword = React.lazy(() => import("./pages/ResetPassword"));
const VerificarEmail = React.lazy(() => import("./pages/VerificarEmail"));
const AguardandoAprovacao = React.lazy(() => import("./pages/AguardandoAprovacao"));
const GerenciarUsuarios = React.lazy(() => import("./pages/Admin/GerenciarUsuarios"));
const GerenciarEmpresas = React.lazy(() => import("./pages/Admin/GerenciarEmpresas"));
const GerenciarMensagens = React.lazy(() => import("./pages/Admin/GerenciarMensagens"));
const CadastrarEmpresa = React.lazy(() => import("./pages/Admin/CadastrarEmpresa"));
const CadastrarUsuario = React.lazy(() => import("./pages/Admin/CadastrarUsuario"));
const CadastrarApi = React.lazy(() => import("./pages/Admin/CadastrarApi"));
const EditarApi = React.lazy(() => import("./pages/Admin/EditarApi"));
const GerenciarApis = React.lazy(() => import("./pages/Admin/GerenciarApis"));
const IAs = React.lazy(() => import("./pages/Admin/IAs"));
const Dashboard = React.lazy(() => import("./pages/Dashboard/Index"));
const Projetos = React.lazy(() => import("./pages/Dashboard/Projetos"));
const Configuracoes = React.lazy(() => import("./pages/Dashboard/Configuracoes"));
const ClientesList = React.lazy(() => import("./pages/Dashboard/Clientes/ClientesList"));
const ClienteDetail = React.lazy(() => import("./pages/Dashboard/Clientes/ClienteDetail"));
const ApiDetail = React.lazy(() => import("./pages/Dashboard/Clientes/ApiDetail"));
const NotFound = React.lazy(() => import("./pages/NotFound"));

// Loading component otimizado
const PageLoader = () => (
  <div className="flex items-center justify-center min-h-screen bg-gradient-to-br from-slate-50 to-slate-100">
    <div className="relative">
      <div className="animate-spin rounded-full h-12 w-12 border-2 border-primary border-t-transparent"></div>
      <div className="absolute inset-0 animate-ping rounded-full h-12 w-12 border border-primary opacity-20"></div>
    </div>
  </div>
);

// Componente interno para usar os hooks
const AppContent = () => {
  useResourceOptimization();

  const [queryClient] = React.useState(() => new QueryClient({
    defaultOptions: {
      queries: {
        staleTime: 5 * 60 * 1000, // 5 minutes
        gcTime: 10 * 60 * 1000, // 10 minutes
        retry: 1,
        refetchOnWindowFocus: false,
      },
    },
  }));

  return (
    <QueryClientProvider client={queryClient}>
      <ThemeProvider defaultTheme="light">
        <TooltipProvider>
          <BrowserRouter>
            <AuthProvider>
              <CriticalCSSLoader>
                <Toaster />
                <Sonner />
                <Suspense fallback={<PageLoader />}>
                  <Routes>
                    <Route path="/" element={<Index />} />
                    <Route path="/servicos" element={<ServicosPage />} />
                    <Route path="/sobre" element={<SobrePage />} />
                    <Route path="/contato" element={<ContatoPage />} />
                    <Route path="/login" element={<LoginPage />} />
                    <Route path="/reset-password" element={<ResetPassword />} />
                    <Route path="/verificar-email" element={<VerificarEmail />} />
                    <Route path="/aguardando-aprovacao" element={<AguardandoAprovacao />} />
                    
                    <Route path="/dashboard" element={<ProtectedRoute requireActive={true} />}>
                      <Route element={<DashboardLayout />}>
                        <Route index element={<Dashboard />} />
                        <Route path="projetos" element={<Projetos />} />
                        <Route path="configuracoes" element={<Configuracoes />} />
                        <Route path="clientes" element={<ClientesList />} />
                        <Route path="clientes/:clientId" element={<ClienteDetail />} />
                        <Route path="clientes/:clientId/apis/:apiId" element={<ApiDetail />} />
                        
                        <Route path="usuarios" element={<GerenciarUsuarios />} />
                        <Route path="cadastrar-usuario" element={<CadastrarUsuario />} />
                      </Route>
                    </Route>
                    
                    <Route path="/admin" element={<ProtectedRoute requireAdmin={true} />}>
                      <Route element={<DashboardLayout />}>
                        <Route index element={<Dashboard />} />
                        <Route path="usuarios" element={<GerenciarUsuarios />} />
                        <Route path="empresas" element={<GerenciarEmpresas />} />
                        <Route path="mensagens" element={<GerenciarMensagens />} />
                        <Route path="apis" element={<GerenciarApis />} />
                        <Route path="cadastrar-empresa" element={<CadastrarEmpresa />} />
                        <Route path="cadastrar-usuario" element={<CadastrarUsuario />} />
                        <Route path="cadastrar-api" element={<CadastrarApi />} />
                        <Route path="apis/:apiId/editar" element={<EditarApi />} />
                        <Route path="ias" element={<IAs />} />
                      </Route>
                    </Route>
                    
                    <Route path="*" element={<NotFound />} />
                  </Routes>
                </Suspense>
              </CriticalCSSLoader>
            </AuthProvider>
          </BrowserRouter>
        </TooltipProvider>
      </ThemeProvider>
    </QueryClientProvider>
  );
};

const App = () => {
  return <AppContent />;
};

export default App;
